@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber;
-$Test::BDD::Cucumber::VERSION = '0.48';
+$Test::BDD::Cucumber::VERSION = '0.49';
 use strict;
 use warnings;
 1;
@@ -12,7 +12,7 @@ Test::BDD::Cucumber - Feature-complete Cucumber-style testing in Perl
 
 =head1 VERSION
 
-version 0.48
+version 0.49
 
 =head1 DESCRIPTION
 
@@ -24,7 +24,17 @@ L<See the logged issue|https://github.com/pjlsergeant/test-bdd-cucumber-perl/iss
 
 =head1 QUICK LINKS
 
-L<Cucumber on Perl on MetaCPAN|https://metacpan.org/release/Test-BDD-Cucumber>
+See this distribution: L<Cucumber on Perl on MetaCPAN|https://metacpan.org/release/Test-BDD-Cucumber>
+
+=begin html
+
+You can talk to the author(s) here: <a
+href="https://gitter.im/pjlsergeant/test-bdd-cucumber-perl"><img
+    src="https://badges.gitter.im/pjlsergeant/test-bdd-cucumber-perl.svg"
+    alt="Chat on Gitter"
+></a>
+
+=end html
 
 =head1 NEXT STEPS
 
@@ -68,6 +78,8 @@ On Github, of course: L<https://github.com/pjlsergeant/test-bdd-cucumber-perl>.
 
 Peter Sergeant C<pete@clueball.com>
 
+Erik Huelsmann C<ehuels@gmail.com>
+
 Ben Rodgers C<ben@bdr.org>
 
 =head1 LICENSE
